@@ -1,5 +1,6 @@
 #!/usr/bin/python3
 
+import apt
 import subprocess
 import os
 import re
@@ -16,6 +17,10 @@ KERNEL_INFO_DIR = "/usr/share/mint-kernel-info"
 VERSION_GROUP = Gtk.SizeGroup(Gtk.SizeGroupMode.HORIZONTAL)
 INFO_GROUP = Gtk.SizeGroup(Gtk.SizeGroupMode.HORIZONTAL)
 
+# Kernel package names
+KERNEL_PKG_NAMES = ['linux-headers-VERSION', 'linux-headers-VERSION-generic', 'linux-image-VERSION-generic', 'linux-modules-VERSION-generic', 'linux-modules-extra-VERSION-generic']
+KERNEL_PKG_NAMES.append('linux-image-extra-VERSION-generic') # Naming convention in 16.04, until 4.15 series
+
 def list_header_func(row, before, user_data):
     if before and not row.get_header():
         row.set_header(Gtk.Separator(orientation=Gtk.Orientation.HORIZONTAL))
@@ -30,24 +35,22 @@ class InstallKernelThread(threading.Thread):
 
     def run(self):
         cmd = ["pkexec", "/usr/sbin/synaptic", "--hide-main-window",  \
-                "--non-interactive", "--parent-window-id", "%s" % self.window.get_window().get_xid()]
-        cmd.append("-o")
-        cmd.append("Synaptic::closeZvt=true")
-        cmd.append("--progress-str")
-        cmd.append("\"" + _("Please wait, this can take some time") + "\"")
-        cmd.append("--finish-str")
-        if self.remove:
-            cmd.append("\"" + _("The %s kernel was removed") % self.version + "\"")
-        else:
-            cmd.append("\"" + _("The %s kernel was installed") % self.version + "\"")
+                "--non-interactive", "--parent-window-id", "%s" % self.application.window.get_window().get_xid(), "-o", "Synaptic::closeZvt=true"]
         f = tempfile.NamedTemporaryFile()
 
-        for pkg in ['linux-headers-%s' % self.version, 'linux-headers-%s-generic' % self.version, 'linux-image-%s-generic' % self.version, 'linux-image-extra-%s-generic' % self.version]:
-            if self.remove:
-                pkg_line = "%s\tpurge\n" % pkg
-            else:
-                pkg_line = "%s\tinstall\n" % pkg
-            f.write(pkg_line.encode("utf-8"))
+        cache = apt.Cache()
+        for name in KERNEL_PKG_NAMES:
+            name = name.replace("VERSION", self.version)
+            if name in cache:
+                pkg = cache[name]
+                if self.remove:
+                    if pkg.is_installed:
+                        pkg_line = "%s\tpurge\n" % name
+                        f.write(pkg_line.encode("utf-8"))
+                else:
+                    pkg_line = "%s\tinstall\n" % name
+                    f.write(pkg_line.encode("utf-8"))
+
         cmd.append("--set-selections-file")
         cmd.append("%s" % f.name)
         f.flush()
@@ -226,7 +229,7 @@ class KernelWindow():
 
         builder.get_object("title_warning").set_markup("<span font_weight='bold' size='x-large'>%s</span>" % _("Warning!"))
         builder.get_object("sub_title_warning").set_markup("<big><b>%s</b></big>" % _("Proceed with caution"))
-        builder.get_object("label_warning").set_markup(_("The Linux kernel is a critical part of the system. Regressions can lead to lack of networking, lack of sound, lack of graphical environment or even the inability to boot the computer. Only install or remove kernels if you are experienced with kernels, drivers, DKMS modules and you know how to recover a non-booting computer."))
+        builder.get_object("label_warning").set_markup(_("The Linux kernel is a critical part of the system. Regressions can lead to lack of networking, lack of sound, lack of graphical environment or even the inability to boot the computer."))
         builder.get_object("label_more_info_1").set_markup("%s" % _("Before installing or removing kernels, please make sure to read the help section, to make sure you know how to select kernels, how to revert updates and how to check your DKMS status."))
 
         # Setup the main kernel page
