@@ -52,13 +52,7 @@ cache.open(None)
 cache.upgrade(dist_upgrade)
 changes = cache.get_changes()
 
-cmd = ["sudo", "/usr/sbin/synaptic", "--hide-main-window", "--non-interactive", "--parent-window-id", "%s" % window_id]
-cmd.append("-o")
-cmd.append("Synaptic::closeZvt=true")
-cmd.append("--progress-str")
-cmd.append("\"" + _("Please wait, this can take some time") + "\"")
-cmd.append("--finish-str")
-cmd.append("\"" + _("Update is complete") + "\"")
+cmd = ["sudo", "/usr/sbin/synaptic", "--hide-main-window", "--non-interactive", "--parent-window-id", "%s" % window_id, "-o", "Synaptic::closeZvt=true"]
 f = tempfile.NamedTemporaryFile()
 
 for pkg in changes:
@@ -89,13 +83,6 @@ returnCode = comnd.wait()
 #--------------------
 
 try:
-    if os.path.exists("/etc/grub.d/10_linux"):
-        if os.path.exists("/etc/linuxmint/info"):
-            mint_grub_title = subprocess.getoutput("grep GRUB_TITLE /etc/linuxmint/info | awk -F = '{print $2}'")
-        else:
-            mint_grub_title = "Linux Mint"
-        os.system("sed -i -e 's@OS=\"${GRUB_DISTRIBUTOR}\"@OS=\"%s\"@g' /etc/grub.d/10_linux" % mint_grub_title)
-        os.system("sed -i -e 's@OS=\"Linux Mint .*@OS=\"%s\"@g' /etc/grub.d/10_linux" % mint_grub_title)
-        subprocess.call("update-grub")
+    subprocess.call("update-grub")
 except Exception as detail:
     syslog.syslog("Couldn't update grub: %s" % detail)
\ No newline at end of file
